@@ -13,7 +13,7 @@ class FocalLoss(nn.Module):
         self.gamma = gamma
 
     def forward(self, x, target):
-        eps = np.finfo(float).epsilon
+        eps = np.finfo(float).eps
         p_t = torch.where(target == 1, x, 1-x)
         fl = - 1 * (1 - p_t) ** self.gamma * torch.log(p_t + eps)
         fl = torch.where(target == 1, fl * self.alpha, fl * (1 - self.alpha))
